# RayyanStore

RayyanStore ruby client.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'rayyan-store'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install rayyan-store

## Usage

TODO:
- document article schema
- document available facet keys
- document available filter keys

```ruby
    # require and initialize client
    require 'rayyan-store'
    # ENV['RAYYAN_STORE_URL'] must be set
    rayyan_store = RayyanStore::Client.new

    review_id = 1 # review_id here

    # delete review (if existing)
    rayyan_store.delete_review(review_id)

    # create review
    rayyan_store.create_review(review_id)

    # delete by file_id in case previous bulk imports failed
    rayyan_store.delete_by_file_id(review_id, file_id)

    # bulk import articles
    article1 = {title: 'my title1', authors: ['author1', 'author2']} # ...
    article2 = {title: 'my title2', authors: ['author1', 'author2']} # ...
    batch = [article1, article2] # ...
    ids = rayyan_store.import review_id, batch

    # get total number of articles for a review
    total = rayyan_store.total(review_id)

    # get facets
    facet_rows = rayyan_store.facet(review_id, facet_key, user_ids)

    # insert customization
    key = 'included'
    value = 1 # 1 for included, -1 for excluded, 0 for maybe
    rayyan_store.insert_customization(review_id, article_id, user_id, key, value)
    key = 'my label' # no value required
    rayyan_store.insert_customization(review_id, article_id, user_id, key)
    key = '__EXR__my exclusion reason' # no value required
    rayyan_store.insert_customization(review_id, article_id, user_id, key)

    # delete customization
    rayyan_store.delete_customization(review_id, article_id, user_id, key)

    # export articles page
    # note that to get first page, last_id should be nil
    last_id = rayyan_store.export(review_id, 'articles', last_id, length)
    # export customizations log page
    last_id = rayyan_store.export(review_id, 'customizations_log', last_id, length)
    # note that export yields articles/customization_logs one by one

    # stream-export all articles
    rayyan_store.stream_export(review_id, 'articles')
    rayyan_store.stream_export(review_id, 'customizations_log')
    # note that stream-export yields articles/customization_logs one by one

    # query
    return_total = true
    filter = {}
    total = rayyan_store.query(review_id, filter, start_index, length, return_total)
    # note that query yields articles one by one
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`.

## Releasing

```bash
docker build . -t rayyan-store:1
docker run -it --rm -v $PWD:/home rayyan-store:1
docker run -it --rm rayyan-store:1 /home/publish.sh
```

Enter your email and password when prompted. If you want to skip interactive
login, supply `RUBYGEMS_API_KEY` as an additional argument:

```bash
docker run -it --rm -e RUBYGEMS_API_KEY=YOUR_RUBYGEMS_API_KEY rayyan-store:1 /home/publish.sh
```

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).
